# Linear Search

This is the most basic and intuitive searching algorithm. We start from the left most index and check if the given element is equal to the number. If yes, we return the index. If we pass through the whole list and don't find the number, we return -1.

### Time Complexity
* Worst complexity: O(n)
* Average complexity: O(n)
* Best case: O(1)


### Space Complexity
* Space complexity: O(1)
* Worst-case space complexity: O(1) iterative